print("import: 'botocore'")
import botocore

print("import: 'botocore.docs'")
import botocore.docs

print("import: 'botocore.docs.bcdoc'")
import botocore.docs.bcdoc

print("import: 'botocore.vendored'")
import botocore.vendored

print("import: 'botocore.vendored.requests'")
import botocore.vendored.requests

print("import: 'botocore.vendored.requests.packages'")
import botocore.vendored.requests.packages

print("import: 'botocore.vendored.requests.packages.urllib3'")
import botocore.vendored.requests.packages.urllib3

